% ---------------------------------------------------------------------
% Conference proceedings and article templates for
% personal open-archiving activities
% September 2012
% ---------------------------------------------------------------------

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{SelfArx2}[25/01/2012, v1.0]
\RequirePackage{ifthen}
\RequirePackage{calc}
\AtEndOfClass{\RequirePackage{microtype}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions*
\LoadClass{article}

%\RequirePackage{txfonts}      % Loads the Times-Roman Fonts
%\gdef\ttdefault{cmtt}%
   %\let\iint\relax
  %\let\iiint\relax
  %\let\iiiint\relax
  %\let\idotsint\relax
%  \let\openbox\relax
%\RequirePackage{mathptmx}   % Loads the Times-Roman Math Fonts
\RequirePackage{ifpdf}      % Needed to pick between latex and pdflatex

% ---------------------------------------------------------------------
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage{amsmath}
\RequirePackage{multicol}
\RequirePackage{graphicx,xcolor}
\RequirePackage[english]{babel}
\RequirePackage{booktabs}
\RequirePackage{siunitx}
% ---------------------------------------------------------------------
\definecolor{vert}{RGB}{46,132,166}
\definecolor{rouge}{RGB}{136,74,76}
\definecolor{color2}{RGB}{0,0,0}
\colorlet{color1}{color2!50}
% ---------------------------------------------------------------------
%%%%% for abstract+authors frames
% ---------------------------------------------------------------------		
% margins		
\RequirePackage{geometry}%
 \geometry{paperwidth=210mm,
  paperheight=297mm,
  top=30pt,
  bottom=35pt,
  textwidth=525pt,
  centering,
  headheight=12pt,
  headsep=12pt,
  footskip=25pt,
  %showframe,
  %footnotesep=24pt plus 2pt minus 12pt
 }%
\RequirePackage[labelsep=period]{caption}%
\DeclareCaptionFont{color2}{\color{color2}}%
\captionsetup{labelfont={color2,bf,sf,footnotesize},font={color2,small}}%
\captionsetup[table]{aboveskip=6pt,belowskip=0pt}%
\captionsetup[figure]{aboveskip=3pt,belowskip=0pt}%
% ---------------------------------------------------------------------
\RequirePackage{fancyhdr}  % Needed to define custom headers/footers
%\RequirePackage{lastpage}  % Number of pages in the document
\pagestyle{fancy}          % Enables the custom headers/footers
% Headers
\lhead{}%
\chead{}%
\rhead{}
% Footers
\lfoot{}%
\cfoot{\thepage}%
\rfoot{}%
\renewcommand{\headrulewidth}{0pt}% % No header rule
\renewcommand{\footrulewidth}{0pt}% % No footer rule
% ---------------------------------------------------------------------
% section/subsection/paragraph set-up
\RequirePackage[explicit]{titlesec}
\titleformat{\section}
  {\bfseries\sffamily}
  {}
 {0em}
  {\thesection. #1}
  []
\titleformat{name=\section,numberless}
  {\bfseries\sffamily}
  {}
  {0em}
  {#1}
  []
\titleformat{\subsection}
  {\bfseries\sffamily\small}
  {\thesubsection}
  {0.5em}
  {#1}
  []
\titleformat{\subsubsection}
  {\color{color2}\bfseries\sffamily\small\itshape}
  {\thesubsubsection}
  {0.5em}
  {#1}
  []
\titleformat{\paragraph}[runin]
  {\sffamily\small\bfseries}
  {}
  {0em}
  {#1}
\titlespacing*{\section}{0pc}{3ex \@plus4pt \@minus3pt}{0pt}
\titlespacing*{\subsection}{0pc}{2.5ex \@plus3pt \@minus2pt}{0pt}
\titlespacing*{\subsubsection}{0pc}{2ex \@plus2.5pt \@minus1.5pt}{0pt}
\titlespacing*{\paragraph}{0pc}{1.5ex \@plus2pt \@minus1pt}{10pt}
% ---------------------------------------------------------------------
% tableofcontents set-up
\setcounter{tocdepth}{2}%
\newlength\tocsep%
\setlength{\tocsep}{.3cm}%
\usepackage{titletoc}%
\contentsmargin{0cm}%
\titlecontents{section}[\tocsep]%
  {\addvspace{2pt}\scriptsize\bfseries\sffamily}%
  {\color{color1}\contentslabel[\thecontentslabel]{\tocsep}}%
  {}%
  {\color{color1}\ \titlerule*[.5pc]{.}\ \thecontentspage}%
  []%
\titlecontents*{subsection}[\tocsep]%
  {\addvspace{0pt}\scriptsize\sffamily}%
  {}%
  %{\contentslabel[\thecontentslabel]{\tocsep}}
  {}%
  %{\ \titlerule*[.5pc]{.}\ \thecontentspage}
  {}%
  [\color{color1}\;\textbullet\;]%
\titlecontents*{subsubsection}[\tocsep]%
  {\footnotesize\sffamily}%
  {}%
  {}%
  {}%
  [\textbullet]%
\titlecontents*{paragraph}[\tocsep]%
  {\footnotesize\sffamily}%
  {}%
  {}%
  {}%
  [\textbullet]%
% ---------------------------------------------------------------------
% Get the multiple author set
\newcount\@authcnt
\newcount\@tmpcnt\@tmpcnt\z@

\def\@affiliation{%
  \ifnum\@tmpcnt<\@authcnt
   \global\advance\@tmpcnt1
    \raggedright \csname @auth\romannumeral\the\@tmpcnt\endcsname\hfill\\%
   \let\next\@affiliation \vskip1pt
  \else
   \let\next\relax
  \fi
\next}
	
\newcommand{\affiliation}[1]{%
    \global\advance\@authcnt1
    \expandafter\gdef\csname @auth\romannumeral\the\@authcnt\endcsname
    {#1}}
% ---------------------------------------------------------------------
\RequirePackage{enumitem}
%\setlist{nolistsep} % Uncomment to remove spacing between items in lists (enumerate, itemize)
% ---------------------------------------------------------------------
% Remove brackets from numbering in List of References
\renewcommand{\@biblabel}[1]{\bfseries\color{color1}\textsuperscript{[#1]}}
%\setlength{\bibitemsep}{0cm}
% ---------------------------------------------------------------------
\newcommand{\PaperTitle}[1]{\def\@PaperTitle{#1}}
\newcommand{\Archive}[1]{\def\@Archive{#1}}
\newcommand{\Authors}[1]{\def\@Authors{#1}}
\newcommand{\JournalInfo}[1]{\def\@JournalInfo{#1}}
\newcommand{\Abstract}[1]{\def\@Abstract{#1}}
\newcommand{\Keywords}[1]{\def\@Keywords{#1}}
% ---------------------------------------------------------------------
\renewcommand\tableofcontents{\@starttoc{toc}}
\renewcommand{\@maketitle}{%
\twocolumn[{%
\thispagestyle{empty}%
%\vskip-20pt%
%{\raggedleft\small\itshape\@JournalInfo\par}%
%\vskip20pt%
{\color{color2}\raggedright\Large\bfseries\sffamily\@PaperTitle\par}%
\vskip10pt%
{\raggedright\sffamily\large\selectfont\@Authors\par}
\vskip18pt%
\noindent%
\setlength{\fboxrule}{1pt}%
\setlength{\fboxsep}{3pt}%
\fcolorbox{color1}{white}{%
\parbox[t]{\textwidth-2\fboxsep-2\fboxrule}{\centering%
\colorbox{color1!15}{%
\parbox[t]{\textwidth-4\fboxsep-2\fboxrule}{%
\ifx\@Keywords\@empty%
{\small\sffamily\bfseries\textcolor{color2}{\abstractname}}\small\hskip10pt\@Abstract%
\else%
{\small\sffamily\bfseries\textcolor{color2}{\abstractname}}\small\hskip10pt\@Abstract\\[5pt]%
{\small\sffamily\bfseries\textcolor{color2}{\keywordname}}\small\hskip10pt\@Keywords%\\[-5pt]
%{\small\sffamily\bfseries Contents}
%\begin{multicols}{2}
%\tableofcontents%
%\end{multicols}
\fi}}%
\vskip5pt%
\begingroup%
\sffamily\scriptsize\@affiliation\par%
\endgroup%%
}%
}%
\vskip 29pt plus 10pt minus 3pt%
}]%
}%
% ---------------------------------------------------------------------
\let\oldbibliography\thebibliography
\renewcommand{\thebibliography}[1]{%
\addcontentsline{toc}{section}{\hspace*{-\tocsep}\refname}%
\oldbibliography{#1}%
\setlength\itemsep{0pt}}%
% ---------------------------------------------------------------------
% nomenclature
% ---------------------------------------------------------------------
%\patchcmd{\thenomenclature}
% {\section*{\nomname}}
%  {{\bfseries\sffamily\textcolor{color2}{\nomname}}}
%  {}{}
%\makenomenclature

%\renewcommand{\nomgroup}[1]
%{%
%    \ifthenelse{\equal{#1}{A}}
%    {\item[]\hspace*{-\leftmargin}%
%    {\color{color2}\textbf{Roman symbols}}}
%    {%
%        \ifthenelse{\equal{#1}{B}}
%        {\vspace{3\parsep}\item[]\hspace*{-\leftmargin}%
%        {\color{color2}\textbf{Greek symbols and maths}}}
%        {%
%            \ifthenelse{\equal{#1}{C}}
%            {\vspace{3\parsep}\item[]\hspace*{-\leftmargin}%
%            {\color{color2}\textbf{Abbreviations}}}
%        }
%    }
%}
\usepackage{array}
\usepackage{siunitx}
%\usepackage{tikz}
%\usepackage{pgfplots}
%\pgfplotsset{compat=newest}
%\newcommand{\refline}[1]{(\protect\tikz{\protect\fill[white] (0,-0.3em) rectangle (1.8em,0.3em);\protect\draw[#1] (0,0) -- (1.8em,0);})}
%\newcommand{\refarea}[1]{(\protect\tikz{\protect\fill[#1] (0,-0.3em) rectangle (1.8em,0.3em);})}
%\newcommand{\refdot}[1]{(\protect\tikz{\protect\node[scale=0.5,solid,draw,very thick,#1,circle]{};})}
%\newcommand{\echelle}{(\protect\tikz{\protect\node[]{\includegraphics{colormap}};})}
%\newcommand{\refbox}[1]{\smash{\protect\tikz[baseline=-3pt]{\protect\node[solid,draw,thick,color2,rectangle,fill=white,inner sep=2pt] {\vphantom{d}#1};}}}
%\usetikzlibrary{arrows}
%\definecolor{darkgreen}{rgb}{0.125,0.5,0.169}

%\usepackage{rotating}
%\usetikzlibrary{shapes}
%\usepackage[abs]{overpic}
%\usepackage{subfig}
%\setlength\unitlength{1mm}

%\graphicspath{{Figures/Drawings/}{Figures/Tikz/}}

% Color of the article title and sections
%\colorlet{color2}{color1!50} % Color of the boxes behind the abstract and headings
%%\newcommand{\gr}{\textcolor{vert}}
%\newcommand{\rem}{\textcolor{red}}
\newcommand*\D{\mathop{}\!\mathrm{d}}
\DeclareMathOperator{\trace}{tr}
\setlength{\columnsep}{14pt}
